# Changelog

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. All closed issued and bug fixes should be 
represented by the pull requests that fixed them.
Critical items to know are:

 - renamed commands
 - deprecated / removed commands
 - changed defaults
 - backward incompatible changes
 - migration guidance
 - changed behaviour

versions here coincide with releases on pypi.

## [master](https://github.com/openbases/openbases-python/tree/master)
 - added base functions to get fields from paper markdown and tests (0.0.0)
 - package registration (still under development)
